@@ -4,14 +4,17 @@ use strict;
 use warnings;
 use 5.010_000;
 
-our $VERSION = '2.028013';
+our $VERSION = '2.029001';
 use App::Netdisco::Configuration;
 
+use Module::Find ();
+Module::Find::usesub 'App::NetdiscoE::Init';
+
 =head1 NAME
 
 App::Netdisco - An open source web-based network management tool.
 
-=head1 Introduction
+=head1 DESCRIPTION
 
 Netdisco is a web-based network management tool designed for network
 administrators. Data is collected into a PostgreSQL database using SNMP.
