@@ -3,6 +3,11 @@ package App::Netdisco::Configuration;
 use App::Netdisco::Environment;
 use Dancer ':script';
 
+BEGIN {
+  # stuff useful locations into @INC
+  unshift @INC, @{ (setting('include_paths') || []) };
+}
+
 # set up database schema config from simple config vars
 if (ref {} eq ref setting('database')) {
     my $name = (setting('database')->{name} || 'netdisco');
@@ -58,7 +63,15 @@ delete config->{'housekeeping'};
 # schedule expire used to be called expiry
 setting('schedule')->{expire} ||= setting('schedule')->{expiry}
   if setting('schedule') and exists setting('schedule')->{expiry};
-delete config->{'schedule'}->{'expiry'};
+delete config->{'schedule'}->{'expiry'} if setting('schedule');
+
+# upgrade reports config from hash to list
+if (setting('reports') and ref {} eq ref setting('reports')) {
+    config->{'reports'} = [ map {{
+        tag => $_,
+        %{ setting('reports')->{$_} }
+    }} keys %{ setting('reports') } ];
+}
 
 # set max outstanding requests for AnyEvent::DNS
 $ENV{'PERL_ANYEVENT_MAX_OUTSTANDING_DNS'}
@@ -66,4 +79,7 @@ $ENV{'PERL_ANYEVENT_MAX_OUTSTANDING_DNS'}
 $ENV{'PERL_ANYEVENT_HOSTS'}
   = setting('dns')->{hosts_file} || '/etc/hosts';
 
+# always set this
+$ENV{DBIC_TRACE_PROFILE} = 'console';
+
 true;
