@@ -1,7 +1,9 @@
 package App::Netdisco::Daemon::Worker::Common;
 
 use Dancer qw/:moose :syntax :script/;
+
 use Try::Tiny;
+use App::Netdisco::Util::Daemon;
 
 use Role::Tiny;
 use namespace::clean;
@@ -16,6 +18,7 @@ sub worker_body {
   my $type = $self->worker_type;
 
   while (1) {
+      prctl sprintf 'netdisco-daemon: worker #%s %s: idle', $wid, lc($type);
       my $jobs = jq_take($self->wid, $type);
 
       foreach my $job (@$jobs) {
@@ -23,6 +26,8 @@ sub worker_body {
 
           try {
               $job->started(scalar localtime);
+              prctl sprintf 'netdisco-daemon: worker #%s %s: working on #%s: %s',
+                $wid, lc($type), $job->id, $job->summary;
               info sprintf "$tag (%s): starting %s job(%s) at %s",
                 $wid, $target, $job->id, $job->started;
               my ($status, $log) = $self->$target($job);
@@ -42,9 +47,12 @@ sub worker_body {
 
 sub close_job {
   my ($self, $job) = @_;
-  my $tag = $self->worker_tag;
-  my $now = scalar localtime;
+  my $tag  = $self->worker_tag;
+  my $type = $self->worker_type;
+  my $now  = scalar localtime;
 
+  prctl sprintf 'netdisco-daemon: worker #%s %s: wrapping up %s #%s: %s',
+    $self->wid, lc($type), $job->action, $job->id, $job->status;
   info sprintf "$tag (%s): wrapping up %s job(%s) - status %s at %s",
     $self->wid, $job->action, $job->id, $job->status, $now;
 
