@@ -1,7 +1,9 @@
 package App::Netdisco::Daemon::Worker::Scheduler;
 
 use Dancer qw/:moose :syntax :script/;
+
 use Algorithm::Cron;
+use App::Netdisco::Util::Daemon;
 
 use Role::Tiny;
 use namespace::clean;
@@ -35,8 +37,12 @@ sub worker_body {
   while (1) {
       # sleep until some point in the next minute
       my $naptime = 60 - (time % 60) + int(rand(45));
+
+      prctl sprintf 'netdisco-daemon: worker #%s scheduler: idle', $wid;
       debug "sched ($wid): sleeping for $naptime seconds";
+
       sleep $naptime;
+      prctl sprintf 'netdisco-daemon: worker #%s scheduler: queueing', $wid;
 
       # NB next_time() returns the next *after* win_start
       my $win_start = time - (time % 60) - 1;
